pub struct DirBuilder {
inner: DirBuilder,
recursive: bool,
}Expand description
A builder used to create directories in various manners.
This builder also supports platform-specific options.
Fields
inner: DirBuilderrecursive: boolImplementations
Sourceimpl DirBuilder
impl DirBuilder
1.6.0 · Sourcepub fn new() -> DirBuilder
pub fn new() -> DirBuilder
Creates a new set of options with default mode/security settings for all platforms and also non-recursive.
Examples
1.6.0 · Sourcepub fn recursive(&mut self, recursive: bool) -> &mut Self
pub fn recursive(&mut self, recursive: bool) -> &mut Self
Indicates that directories should be created recursively, creating all parent directories. Parents that do not exist are created with the same security and permissions settings.
This option defaults to false.
Examples
1.6.0 · Sourcepub fn create<P: AsRef<Path>>(&self, path: P) -> Result<()>
pub fn create<P: AsRef<Path>>(&self, path: P) -> Result<()>
Creates the specified directory with the options configured in this builder.
It is considered an error if the directory already exists unless recursive mode is enabled.
Examples
fn _create(&self, path: &Path) -> Result<()>
fn create_dir_all(&self, path: &Path) -> Result<()>